require_relative "boot"

require "rails"
# Pick the frameworks you want:
require "active_model/railtie"
require "active_job/railtie"
# require "active_record/railtie"
# require "active_storage/engine"
require "action_controller/railtie"
require "active_support/time"
# require "action_mailer/railtie"
# require "action_mailbox/engine"
# require "action_text/engine"
require "action_view/railtie"
# require "action_cable/engine"
require "rails/test_unit/railtie"

# Require the gems listed in Gemfile, including any gems
# you've limited to :test, :development, or :production.
Bundler.require(*Rails.groups)

module Frontend
  class Application < Rails::Application
    include GovukPublishingComponents::AppHelpers::AssetHelper
    # Initialize configuration defaults for originally generated Rails version.
    require "frontend"
    config.load_defaults 7.1

    # Set Time.zone default to the specified zone and make Active Record auto-convert to this zone.
    # Run "rake -D time" for a list of tasks for finding time zone names. Default is UTC.
    config.time_zone = "London"

    # Custom directories with classes and modules you want to be autoloadable.
    config.eager_load_paths += %W[#{config.root}/app/presenters #{config.root}/lib]

    # The default locale is :en and all translations from config/locales/*.rb,yml are auto loaded.
    # config.i18n.load_path += Dir[Rails.root.join('my', 'locales', '*.{rb,yml}').to_s]
    config.i18n.default_locale = :en
    config.i18n.fallbacks = true
    config.i18n.available_locales = %i[
      en
      cy
    ]

    # Configure the default encoding used in templates for Ruby 1.9.
    config.encoding = "utf-8"

    # Enable the asset pipeline
    config.assets.enabled = true

    config.assets.precompile += %w[
      views/travel-advice.js
      frontend.js
      application.css
    ]

    # Path within public/ where assets are compiled to
    config.assets.prefix = "/assets/frontend"

    # Configure sensitive parameters which will be filtered from the log file.
    config.filter_parameters += %i[password postcode]

    # Disable Rack::Cache
    config.action_dispatch.rack_cache = nil

    # Disable Content Negotiation
    config.action_dispatch.ignore_accept_header = true

    # Override Rails 4 default which restricts framing to SAMEORIGIN.
    config.action_dispatch.default_headers = {
      "X-Frame-Options" => "ALLOWALL",
    }

    # Settings in config/environments/* take precedence over those specified here.
    # Application configuration can go into files in config/initializers
    # -- all .rb files in that directory are automatically loaded after loading
    # the framework and any gems in your application.

    # Using a sass css compressor causes a scss file to be processed twice
    # (once to build, once to compress) which breaks the usage of "unquote"
    # to use CSS that has same function names as SCSS such as max.
    # https://github.com/alphagov/govuk-frontend/issues/1350
    config.assets.css_compressor = nil
  end
end
